14.82. cdist-type__package(7) — cdist 4.8.1 documentation

# 14.82. cdist-type__package(7)

## 14.82.1. NAME

cdist-type__package - Manage packages

## 14.82.2. DESCRIPTION

This cdist type allows you to install or uninstall packages on the target. It dispatches the actual work to the package system dependent types.

## 14.82.3. REQUIRED PARAMETERS

None

## 14.82.4. OPTIONAL PARAMETERS

name
  The name of the package to install. Default is to use the object_id as the package name.
version
  The version of the package to install. Default is to install the version chosen by the local package manager.
type
  The package type to use. Default is determined based on the $os explorer variable. e.g. * __package_apt for Debian * __package_emerge for Gentoo
state
  Either "present" or "absent", defaults to "present"

## 14.82.5. EXAMPLES

    # Install the package vim on the target
    __package vim --state present

    # Same but install specific version
    __package vim --state present --version 7.3.50

    # Force use of a specific package type
    __package vim --state present --type __package_apt

## 14.82.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 14.82.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.